@@ -530,6 +530,7 @@ class ErrorCodes(object):
         DiscountAmountCannotBeNegative = "915160"
         DiscountAmountFormatIsInvalid = "915159"
         DiscountAmountIsTooLarge = "915161"
+        ExchangeRateQuoteIdIsTooLong = "915229"
         FailedAuthAdjustmentAllowRetry = "95603"
         FailedAuthAdjustmentHardDecline = "95602"
         FinalAuthSubmitForSettlementForDifferentAmount = "95601"
@@ -603,6 +604,7 @@ class ErrorCodes(object):
         SubscriptionStatusMustBePastDue = "91531"
         TaxAmountCannotBeNegative = "81534"
         TaxAmountFormatIsInvalid = "81535"
+        TaxAmountIsRequiredForAibSwedish = "815224"
         TaxAmountIsTooLarge = "81536"
         ThreeDSecureAuthenticationFailed = "81571"
         ThreeDSecureAuthenticationIdDoesntMatchNonceThreeDSecureAuthentication = "915198"
